from ... import util


def parse (lines, meta, api_storage):
    for line in util.strip_empty_lines(lines):
        pass
